|Fonduer|
=========

|Travis| |CodeClimate| |Coveralls| |ReadTheDocs| |PyPI| |PyPIVersion| |GitHubStars| |License| |CodeStyle|

Fonduer is a Python package and framework for building knowledge base
construction (KBC) applications from **richly formatted data**.

Note that Fonduer is still *actively under development*, so feedback and
contributions are welcome. Submit bugs in the Issues_ section or feel free to
submit your contributions as a pull request.

Getting Started
---------------

Check out our `Getting Started Guide`_ to get up and running with Fonduer.

Learning how to use Fonduer
~~~~~~~~~~~~~~~~~~~~~~~~~~~

The `Fonduer tutorials`_ cover the Fonduer workflow, showing how to extract
relations from hardware datasheets and scientific literature.

Reference
---------

`Fonduer: Knowledge Base Construction from Richly Formatted
Data <https://arxiv.org/abs/1703.05028>`__::

    @inproceedings{wu2017fonduer,
      title={Fonduer: Knowledge Base Construction from Richly Formatted Data},
      author={Wu, Sen and Hsiao, Luke and Cheng, Xiao and Hancock, Braden and Rekatsinas, Theodoros and Levis, Philip and R{\'e}, Christopher},
      booktitle={Proceedings of the 2018 International Conference on Management of Data},
      pages={1301--1316},
      year={2018},
      organization={ACM}
    }


Acknowledgements
----------------

Fonduer was inspired by and leverages the work of Snorkel_ and MeTaL_.


.. |CodeClimate| image:: https://img.shields.io/codeclimate/maintainability/HazyResearch/fonduer.svg
   :alt: Code Climate
   :target: https://codeclimate.com/github/HazyResearch/fonduer
.. |Fonduer| image:: docs/static/img/fonduer-logo.png
   :target: https://github.com/HazyResearch/fonduer
.. |Travis| image:: https://img.shields.io/travis/HazyResearch/fonduer/master.svg
   :target: https://travis-ci.org/HazyResearch/fonduer
.. |Coveralls| image:: https://img.shields.io/coveralls/github/HazyResearch/fonduer.svg
   :target: https://coveralls.io/github/HazyResearch/fonduer
.. |ReadTheDocs| image:: https://img.shields.io/readthedocs/fonduer.svg
   :target: https://fonduer.readthedocs.io/
.. |PyPI| image:: https://img.shields.io/pypi/v/fonduer.svg
   :target: https://pypi.org/project/fonduer/
.. |PyPIVersion| image:: https://img.shields.io/pypi/pyversions/fonduer.svg
   :target: https://pypi.org/project/fonduer/
.. |GitHubStars| image:: https://img.shields.io/github/stars/HazyResearch/fonduer.svg
   :target: https://github.com/HazyResearch/fonduer/stargazers
.. |License| image:: https://img.shields.io/github/license/HazyResearch/fonduer.svg
   :target: https://github.com/HazyResearch/fonduer/blob/master/LICENSE
.. |CodeStyle| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black

.. _MeTaL: https://github.com/HazyResearch/metal/
.. _Snorkel: https://hazyresearch.github.io/snorkel/
.. _Issues: https://github.com/HazyResearch/fonduer/issues/
.. _Getting Started Guide: https://fonduer.readthedocs.io/en/latest/user/getting_started.html
.. _Fonduer tutorials: https://github.com/hazyresearch/fonduer-tutorials
.. _Mailing List: https://groups.google.com/forum/#!forum/fonduer-dev
